<?php
if(!class_exists("Gc_Option")){
    class Gc_Option implements Gc_Option_Interface{
        const GC_NS = "gc_message_box_";
        protected $value = null;
        protected $default ="";
        protected $text = "";
        protected $type = "text";
        protected $id = "";
        protected $group ="";
        protected $description = "";
        protected $options = array();
        public function __construct($option_name = null,$default ="",$type = "text",$text = "",$group = ""){
            if(!isset($option_name)){
                return;
            }
            $this->id = $option_name;
            $value = esc_attr(get_option($this->get_name($option_name)));
            $this->default = $default;
            $this->text = $text;
            $this->type = $type;
            $this->group = $group;
            $this->value = empty($value) ? $default : $value;

        }

        public function get_name(){
            return self::GC_NS.$this->id;
        }

        public function get_group(){
            return $this->group;
        }

        public function get_value(){
            return isset($this->value) ? $this->value : $this->default;
        }

        public function set_value($value){
            $this->value = $value;
        }

        public function set_checked($value){
            if($value){
                $this->value = "1";
            } else {
                $this->value = "2";

            }
        }
        
        
        public function get_type(){
            return $this->type;
        }

        public function get_text(){
            return $this->text;
        }

        public function get_description(){
            return $this->description;
        }

        public function get_options(){
            return $this->options;
        }

        public function is_text(){
             return ($this->type == 'text');
        }

        public function is_text_area(){
            return ($this->type  == 'textarea');
        }

        public function is_checkbox(){
            return ($this->type  == 'checkbox');
        }

        public function is_checked(){
            return ($this->value == "1");
        }

        public function is_radio(){
            return ($this->type  == 'radio');
        }

        public function is_color(){
            return ($this->type  == 'color');
        }

        public function is_select(){
             return ($this->type == 'select');
        }

        public function is_number(){
             return ($this->type == 'number');
        }
        


        public function load_from_array(array $params){
            if(isset($params["id"])){
                $this->id = $params["id"];
                $value = esc_attr(get_option($this->get_name($this->id)));
            }
            if(isset($params["type"])){
                $this->type = $params["type"];
            }
            if(isset($params["group"])){
                $this->group = $params["group"];
            }
            if(isset($params["default"])){
                $this->default = $params["default"];
            }
            if(isset($params["text"])){
                $this->text = $params["text"];
            }
            if(isset($params["options"])){
                $this->options = $params["options"];
            }

            if(isset($params["description"])){
                $this->description = $params["description"];
            }
            
            $this->value = empty($value) ? $this->default : $value;

            return $this;


        }



        public static function factory($option_name = null,$default = "",$type = "text",$text = "Text",$group=""){
            if(!isset($option_name)){
                return new Gc_Message_Box_Option();
            }
            return new Gc_Message_Box_Option($option_name, $default,$type,$text,$group);
        }


        public static function get_full_option_name($name){
        	return self::GC_NS.$name;
        }
        
        
        public function is_appear() {
            return strstr($this->id, 'appear_here_');
        }

        
        public function save(){
            $this->save_option($this->id,$this->get_value());
        }

        public function load(){
            $this->value = self::get_option($this->id);
            return $this;
        }

        public function save_option($option_name, $newValue,$deprecated=' ', $autoload='no') {
            if ( $this->get_option( $option_name ) != $newValue ) {
                $this->update_option( $option_name, $newValue );
            } else {
                $deprecated = ' ';
                $autoload = 'no';
                $this->add_option( $option_name, $newValue);
            }
        }
        protected function add_option($option_name,$optionValue, $deprecated=' ', $autoload='no'){
            add_option($this->get_name($option_name),$optionValue, $deprecated, $autoload);
        }
        
        protected function update_option($option_name,$optionValue){
            update_option($this->get_name($option_name),$optionValue);
        }

        public static function get_option($option_name,$default = null){
            return esc_attr(get_option(self::get_full_option_name($option_name)));
        }

        

    }
}